/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.project;

import java.io.IOException;
import nl.cloudfarming.client.stock.model.Stock;
import nl.cloudfarming.client.stock.model.StockManager;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ProjectFactory;
import org.netbeans.spi.project.ProjectState;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;

/**
 *
 * @author Timon Veenstra
 */
@org.openide.util.lookup.ServiceProvider(service = ProjectFactory.class)
public class StockProjectFactory implements ProjectFactory {

    public static final String ICON = "nl/cloudfarming/client/stock/project/box.png";
    public static final String STOCK_FILE = "stock.stk";

    //Specifies when a project is a project, i.e.,
    //if the project directory "texts" is present:
    @Override
    public boolean isProject(FileObject projectDirectory) {
        return projectDirectory.getFileObject(STOCK_FILE) != null;
    }

    //Specifies when the project will be opened, i.e.,
    //if the project exists:
    @Override
    public Project loadProject(FileObject dir, ProjectState state) throws IOException {
        StockProject project = null;
        if (isProject(dir)) {
            StockManager stockManager = Lookup.getDefault().lookup(StockManager.class);
            Stock stock = stockManager.load(dir.getFileObject(STOCK_FILE));
            project = new StockProject(dir, state, stock);
        }

        return project;
    }

    @Override
    public void saveProject(final Project project) throws IOException, ClassCastException {
        FileObject projectRoot = project.getProjectDirectory();
        StockManager farmManager = Lookup.getDefault().lookup(StockManager.class);
        Stock stock = project.getLookup().lookup(Stock.class);
        farmManager.save(stock, projectRoot.createData(STOCK_FILE));
    }
}
