/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.stock.project.visual;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.util.List;
import java.util.logging.Logger;
import javax.imageio.ImageIO;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JSeparator;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.CropBean;
import nl.cloudfarming.client.util.swing.button.ImageButton;
import org.openide.util.NbBundle;
import org.openide.util.NbBundle.Messages;

/**
 *
 * Creates a panel with rows for each provided bean.
 * Will Display provided header label
 * Followed by a row of JLabel JTextField and a delete button.
 * On click of the delete button the row will be removed from the panel.
 * To listen to this changes register as PropertyChangeListener on property ListPanel.PROP_ROW
 * In the propertyChangeEvent the bean which is removed will be the old value
 * @author Merijn Zengers
 */
public class CropProperties extends JPanel { //implements PropertyChangeListener {

    private PropertyChangeSupport propertyChangeSupport;
    private static final int SEPARATOR_WIDTH = 300;
    private JLabel cropSourceLabel;
    private JLabel header;
    private JSeparator separator;
    public static final String PROP_ROW = "row";
    public static final String PROP_SELECTION = "selection";
    private String headerLabel;
    private JPanel innerPanel;
    private Crop crop;
    
    /**
     * This will construct a panel containing the following
     * A header filed with the value provided in @param headerLabel
     * For every bean in @param beans a row of:
     * A JLabel as provided in @param fieldLabel
     * A JTextField for filling the name of the bean
     * A delete button
     * On keyReleases on the JtextField the provided bean.setName() will be invoked with the text of the JTextField 
     * @param beans the beans to build rows for
     * @param headerLabel the Label for the header of the panel
     * @param fieldLabel the label for every field
     */
    CropProperties(Crop crop, String headerLabel) {
        this.crop = crop;
        this.headerLabel = headerLabel;
        init();
    }

    private void init() {
        this.setLayout(new MigLayout("wrap 1"));
        this.setBorder(new EtchedBorder(EtchedBorder.LOWERED));
        header = new JLabel(headerLabel);
        separator = new JSeparator(JSeparator.HORIZONTAL);
        separator.setPreferredSize(new Dimension(SEPARATOR_WIDTH, 0));
        
        this.add(header, "wrap");
        this.add(separator, "wrap");
        
        innerPanel = new JPanel();
        innerPanel.setLayout(new MigLayout("wrap 2, insets 0 0"));

        // Sets text of cropSourceLabel
        cropSourceLabel = new JLabel(crop.getSource());
        
        // Property 'SOURCE'
        innerPanel.add(new JLabel("Crop source:"));
        innerPanel.add(cropSourceLabel);
        //innerPanel.revalidate();
        this.add(innerPanel);
    }

    public void setCrop(Crop crop){
        if(crop != null){
            cropSourceLabel.setText(crop.getSource());
            //cropSourceLabel = new JLabel(crop.getSource());
        }
        else
        {
            cropSourceLabel.setText("");
            //cropSourceLabel = new JLabel("");
        }

    }
//    
//    @Override
//    public void addPropertyChangeListener(PropertyChangeListener pcl) {
//        getPropertyChangeSupport().addPropertyChangeListener(pcl);
//    }
//
//    @Override
//    public void addPropertyChangeListener(String propertyName, PropertyChangeListener pcl) {
//        getPropertyChangeSupport().addPropertyChangeListener(propertyName, pcl);
//    }
//
//    @Override
//    public void removePropertyChangeListener(PropertyChangeListener pcl) {
//        getPropertyChangeSupport().removePropertyChangeListener(pcl);
//    }
//
//    @Override
//    public void removePropertyChangeListener(String propertyName, PropertyChangeListener pcl) {
//        getPropertyChangeSupport().removePropertyChangeListener(propertyName, pcl);
//    }
//
//    PropertyChangeSupport getPropertyChangeSupport() {
//        if (propertyChangeSupport == null) {
//            propertyChangeSupport = new PropertyChangeSupport(this);
//        }
//        return propertyChangeSupport;
//    }
//
//    @Override
//    public void propertyChange(PropertyChangeEvent pce) {
////        if (pce.getPropertyName().equals(Row.PROP_SELECTED) && (Boolean) pce.getNewValue()) {
////            Row old = null;
////            for (Component component : innerPanel.getComponents()) {
////                if (component instanceof Row) {
////                    Row row = (Row) component;
////                    if (row.isSelected() && pce.getSource() != row) {
////                        row.setSelected(false);
////                        old = row;
////                    }
////                }
////            }
////            getPropertyChangeSupport().firePropertyChange(PROP_SELECTION, old, pce.getSource());
////        }
//    }

}
